<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:eur="http://www.eurosion.org/metadataModel/" xmlns:iso19115="http://www.isotc211.org/iso19115/" xmlns:iso19103="http://www.isotc211.org/iso19103/" xmlns:iso19109="http://www.isotc211.org/iso19109/" xmlns:iso4217="http://www.isotc211.org/iso4217/" xmlns:iso639-2="http://www.isotc211.org/iso639-2/" xmlns:gml="http://www.opengis.net/gml" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
	<!-- Copy the nodes and create the ns attribute that saves the namespace -->
	<xsl:template match="*">
		<xsl:element name="{local-name(.)}">
			<xsl:attribute name="ns"><xsl:value-of select="namespace-uri(.)"/></xsl:attribute>
			<xsl:for-each select="@*">
				<xsl:copy/>
			</xsl:for-each>
			<xsl:if test="count(*) > 0 or text()">
				<xsl:apply-templates/>
			</xsl:if>
		</xsl:element>
	</xsl:template>
	<!-- replace the tag name -->
	<xsl:template match="eur:Metadata">
		<xsl:element name="metadata">
			<xsl:copy-of select="namespace::*"/>
			<xsl:attribute name="ns"><xsl:value-of select="namespace-uri(.)"/></xsl:attribute>
			<xsl:for-each select="@*[name(.) != 'xsi:schemaLocation']">
				<xsl:copy/>
			</xsl:for-each>
			<xsl:apply-templates/>
		</xsl:element>
	</xsl:template>
	<!-- replace the Ident tag -->
	<xsl:template match="eur:Ident | eur:DataIdent">
		<xsl:call-template name="replace_tpl">
			<xsl:with-param name="current" select="."/>
			<xsl:with-param name="name" select="'dataIdInfo'"/>
		</xsl:call-template>
	</xsl:template>
	<!-- replace the DQElement by the inherited element -->
	<xsl:template match="iso19115:DQElement">
		<xsl:variable name="recType" select="@xsi:type"/>
		<xsl:variable name="recName">
			<xsl:value-of select="substring($recType, 0, string-length($recType) - string-length('Type') + 1)"/>
		</xsl:variable>
		<xsl:element name="{$recName}">
			<xsl:attribute name="ns">http://www.eurosion.org/metadataModel/</xsl:attribute>
			<xsl:apply-templates/>
		</xsl:element>
	</xsl:template>
	<!-- replace the measResult by the inherited element -->
	<xsl:template match="iso19115:measResult">
		<xsl:variable name="recType" select="@xsi:type"/>
		<xsl:variable name="recName">
			<xsl:value-of select="substring($recType, 0, string-length($recType) - string-length('Type') + 1)"/>
		</xsl:variable>
		<xsl:element name="{$recName}">
			<xsl:attribute name="ns"></xsl:attribute>
			<xsl:apply-templates/>
		</xsl:element>
	</xsl:template>
	<!-- replace the Consts by the inherited element -->
	<xsl:template match="eur:Consts">
		<xsl:variable name="recType" select="@xsi:type"/>
		<xsl:variable name="recName">
			<xsl:value-of select="substring($recType, 0, string-length($recType) - string-length('Type') + 1)"/>
		</xsl:variable>
		<xsl:element name="{$recName}">
			<xsl:attribute name="ns"></xsl:attribute>
			<xsl:apply-templates/>
		</xsl:element>
	</xsl:template>
	<!-- add the uomScale -->
	<xsl:template match="eur:uom">
		<xsl:element name="uom">
			<xsl:element name="UomScale">
				<xsl:apply-templates/>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	<!-- Copy the descKey and create the attribute -->
	<xsl:template match="eur:descKeys">
		<xsl:element name="descKeys">
			<xsl:attribute name="ns"><xsl:value-of select="namespace-uri(.)"/></xsl:attribute>
			<xsl:attribute name="KeyTypCd">
				<xsl:call-template name="keyTyp_value">
				<xsl:with-param name="value" select="keyTyp"/>
				</xsl:call-template>
			</xsl:attribute>
			<xsl:apply-templates/>
		</xsl:element>
	</xsl:template>
	<!-- replace the mdChar tag by mdChar2 because of overlap with esri tags-->
	<xsl:template match="eur:mdChar">
		<xsl:call-template name="replace_tpl">
			<xsl:with-param name="current" select="."/>
			<xsl:with-param name="name" select="'mdChar2'"/>
		</xsl:call-template>
	</xsl:template>
	<!-- replace the mdHrLv tag by mdHrLv2 because of overlap with esri tags-->
	<xsl:template match="eur:mdHrLv">
		<xsl:call-template name="replace_tpl">
			<xsl:with-param name="current" select="."/>
			<xsl:with-param name="name" select="'mdHrLv2'"/>
		</xsl:call-template>
	</xsl:template>
	<!-- replace the mdStanName tag by mdStanName2 because of overlap with esri tags-->
	<xsl:template match="eur:mdStanName">
		<xsl:call-template name="simple_replace_tpl">
			<xsl:with-param name="current" select="."/>
			<xsl:with-param name="name" select="'mdStanName2'"/>
		</xsl:call-template>
	</xsl:template>
	<!-- replace the mdStanVer tag by mdStanVer2 because of overlap with esri tags-->
	<xsl:template match="eur:mdStanVer">
		<xsl:call-template name="simple_replace_tpl">
			<xsl:with-param name="current" select="."/>
			<xsl:with-param name="name" select="'mdStanVer2'"/>
		</xsl:call-template>
	</xsl:template>
	<!-- Definition of a template to replace the name of current node -->
	<xsl:template name="replace_tpl">
		<xsl:param name="current"/>
		<xsl:param name="name"/>
		<xsl:element name="{$name}">
			<xsl:attribute name="ns"><xsl:value-of select="namespace-uri($current)"/></xsl:attribute>
			<xsl:for-each select="@*">
				<xsl:copy/>
			</xsl:for-each>
			<xsl:apply-templates/>
		</xsl:element>
	</xsl:template>
	<xsl:template name="simple_replace_tpl">
		<xsl:param name="current"/>
		<xsl:param name="name"/>
		<xsl:element name="{$name}">
			<xsl:attribute name="ns"><xsl:value-of select="namespace-uri($current)"/></xsl:attribute>
			<xsl:for-each select="@*">
				<xsl:copy/>
			</xsl:for-each>
			<xsl:value-of select="."/>
		</xsl:element>
	</xsl:template>
	<!-- replace the PresForm enum -->
	<xsl:template match="iso19115:presForm">
		<xsl:element name="{local-name(.)}">
			<xsl:attribute name="ns"><xsl:value-of select="namespace-uri(.)"/></xsl:attribute>
			<xsl:element name="PresFormCd">
				<xsl:attribute name="value">
				<xsl:choose>
				<xsl:when test=". = 'documentDigital'">001</xsl:when>
				<xsl:when test=". = 'documentHardcopy'">002</xsl:when>
				<xsl:when test=". = 'imageDigital'">003</xsl:when>
				<xsl:when test=". = 'imageHardcopy'">004</xsl:when>
				<xsl:when test=". = 'mapDigital'">005</xsl:when>
				<xsl:when test=". = 'mapHardcopy'">006</xsl:when>
				<xsl:when test=". = 'modelDigital'">007</xsl:when>
				<xsl:when test=". = 'modelHardcopy'">008</xsl:when>
				<xsl:when test=". = 'profileDigital'">009</xsl:when>
				<xsl:when test=". = 'profileHardcopy'">010</xsl:when>
				<xsl:when test=". = 'tableDigital'">011</xsl:when>
				<xsl:when test=". = 'tableHardcopy'">012</xsl:when>
				<xsl:when test=". = 'videoDigital'">013</xsl:when>
				<xsl:when test=". = 'videoHardcopy'">014</xsl:when>
				<xsl:when test=". = 'collection'">015</xsl:when>
				<xsl:when test=". = 'dataset'">016</xsl:when>
				<xsl:when test=". = 'event'">017</xsl:when>
				<xsl:when test=". = 'image'">018</xsl:when>
				<xsl:when test=". = 'interactiveResource'">019</xsl:when>
				<xsl:when test=". = 'service'">020</xsl:when>
				<xsl:when test=". = 'software'">021</xsl:when>
				<xsl:when test=". = 'sound'">022</xsl:when>
				<xsl:when test=". = 'text'">023</xsl:when>
				<xsl:otherwise>001</xsl:otherwise>
				</xsl:choose>
				</xsl:attribute>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	<!-- replace the refDateType enum -->
	<xsl:template match="iso19115:refDateType">
		<xsl:element name="{local-name(.)}">
			<xsl:attribute name="ns"><xsl:value-of select="namespace-uri(.)"/></xsl:attribute>
			<xsl:element name="DateTypCd">
				<xsl:attribute name="value"><xsl:choose><xsl:when test=". = 'creation'">001</xsl:when><xsl:when test=". = 'publication'">002</xsl:when><xsl:when test=". = 'revision'">003</xsl:when><xsl:when test=". = 'modified'">004</xsl:when><xsl:when test=". = 'issued'">005</xsl:when><xsl:when test=". = 'validation'">006</xsl:when><xsl:when test=". = 'available'">007</xsl:when><xsl:otherwise>001</xsl:otherwise></xsl:choose></xsl:attribute>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	<!-- replace the role enum -->
	<xsl:template match="iso19115:role">
		<xsl:element name="{local-name(.)}">
			<xsl:attribute name="ns"><xsl:value-of select="namespace-uri(.)"/></xsl:attribute>
			<xsl:element name="RoleCd">
				<xsl:attribute name="value"><xsl:choose><xsl:when test=". = 'resourceProvider'">001</xsl:when><xsl:when test=". = 'custodian'">002</xsl:when><xsl:when test=". = 'owner'">003</xsl:when><xsl:when test=". = 'user'">004</xsl:when><xsl:when test=". = 'distributor'">005</xsl:when><xsl:when test=". = 'originator'">006</xsl:when><xsl:when test=". = 'pointOfContact'">007</xsl:when><xsl:when test=". = 'principalInvestigator'">008</xsl:when><xsl:when test=". = 'processor'">009</xsl:when><xsl:when test=". = 'publisher'">010</xsl:when><xsl:when test=". = 'author'">011</xsl:when><xsl:otherwise>001</xsl:otherwise></xsl:choose></xsl:attribute>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	<!-- replace the spatRpType enum -->
	<xsl:template match="eur:spatRpType">
		<xsl:element name="{local-name(.)}">
			<xsl:attribute name="ns"><xsl:value-of select="namespace-uri(.)"/></xsl:attribute>
			<xsl:element name="spatRepTypCd">
				<xsl:attribute name="value"><xsl:choose><xsl:when test=". = 'vector'">001</xsl:when><xsl:when test=". = 'grid'">002</xsl:when><xsl:when test=". = 'textTable'">003</xsl:when><xsl:when test=". = 'tin'">004</xsl:when><xsl:when test=". = 'stereoModel'">005</xsl:when><xsl:when test=". = 'video'">006</xsl:when><xsl:otherwise>001</xsl:otherwise></xsl:choose></xsl:attribute>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	<!-- replace the tpCat enum -->
	<xsl:template match="eur:tpCat">
		<xsl:element name="{local-name(.)}">
			<xsl:attribute name="ns"><xsl:value-of select="namespace-uri(.)"/></xsl:attribute>
			<xsl:element name="TopicCatCd">
				<xsl:attribute name="value">
				<xsl:choose>
				<xsl:when test=". = 'farming'">001</xsl:when>
				<xsl:when test=". = 'biota'">002</xsl:when>
				<xsl:when test=". = 'boundaries'">003</xsl:when>
				<xsl:when test=". = 'climatologyMeteorologyAtmosphere'">004</xsl:when>
				<xsl:when test=". = 'economy'">005</xsl:when>
				<xsl:when test=". = 'elevation'">006</xsl:when>
				<xsl:when test=". = 'environment'">007</xsl:when>
				<xsl:when test=". = 'geoscientificInformation'">008</xsl:when>
				<xsl:when test=". = 'health'">009</xsl:when>
				<xsl:when test=". = 'imageryBaseMapsEarthCover'">010</xsl:when>
				<xsl:when test=". = 'intelligenceMilitary'">011</xsl:when>
				<xsl:when test=". = 'inlandWaters'">012</xsl:when>
				<xsl:when test=". = 'location'">013</xsl:when>
				<xsl:when test=". = 'oceans'">014</xsl:when>
				<xsl:when test=". = 'planningCadastre'">015</xsl:when>
				<xsl:when test=". = 'society'">016</xsl:when>
				<xsl:when test=". = 'structure'">017</xsl:when>
				<xsl:when test=". = 'transportation'">018</xsl:when>
				<xsl:when test=". = 'utilitiesCommunication'">019</xsl:when>
				<xsl:otherwise>001</xsl:otherwise>
				</xsl:choose></xsl:attribute>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	<!-- replace the maintFreq enum -->
	<xsl:template match="eur:maintFreq">
		<xsl:element name="{local-name(.)}">
			<xsl:attribute name="ns"><xsl:value-of select="namespace-uri(.)"/></xsl:attribute>
			<xsl:element name="MaintFreqCd">
				<xsl:attribute name="value"><xsl:choose><xsl:when test=". = 'continual'">001</xsl:when><xsl:when test=". = 'daily'">002</xsl:when><xsl:when test=". = 'weekly'">003</xsl:when><xsl:when test=". = 'fortnightly'">004</xsl:when><xsl:when test=". = 'monthly'">005</xsl:when><xsl:when test=". = 'quarterly'">006</xsl:when><xsl:when test=". = 'biannually'">007</xsl:when><xsl:when test=". = 'annually'">008</xsl:when><xsl:when test=". = 'asNeeded'">009</xsl:when><xsl:when test=". = 'irregular'">010</xsl:when><xsl:when test=". = 'notPlanned'">011</xsl:when><xsl:when test=". = 'unknown'">012</xsl:when><xsl:otherwise>001</xsl:otherwise></xsl:choose></xsl:attribute>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	<!-- replace the accessConsts enum -->
	<xsl:template match="eur:accessConsts | eur:useConsts">
		<xsl:element name="{local-name(.)}">
			<xsl:attribute name="ns"><xsl:value-of select="namespace-uri(.)"/></xsl:attribute>
			<xsl:element name="RestrictCd">
				<xsl:attribute name="value"><xsl:choose><xsl:when test=". = 'copyright'">001</xsl:when><xsl:when test=". = 'patent'">002</xsl:when><xsl:when test=". = 'patentPending'">003</xsl:when><xsl:when test=". = 'trademark'">004</xsl:when><xsl:when test=". = 'license'">005</xsl:when><xsl:when test=". = 'intellectualPropertyRights'">006</xsl:when><xsl:when test=". = 'restricted'">007</xsl:when><xsl:when test=". = 'otherRestrictions'">008</xsl:when><xsl:otherwise>001</xsl:otherwise></xsl:choose></xsl:attribute>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	<!-- replace the keyTyp enum -->
	<xsl:template match="eur:keyTyp">
		<xsl:element name="{local-name(.)}">
			<xsl:attribute name="ns"><xsl:value-of select="namespace-uri(.)"/></xsl:attribute>
			<xsl:element name="KeyTypCd">
				<xsl:attribute name="value"><xsl:choose><xsl:when test=". = 'discipline'">001</xsl:when><xsl:when test=". = 'place'">002</xsl:when><xsl:when test=". = 'temporal'">003</xsl:when><xsl:when test=". = 'stratum'">004</xsl:when><xsl:when test=". = 'theme'">005</xsl:when><xsl:otherwise>001</xsl:otherwise></xsl:choose></xsl:attribute>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	<xsl:template name="keyTyp_value">
	<xsl:param name="value"></xsl:param>
		<xsl:choose>
		<xsl:when test="$value = 'discipline'">001</xsl:when>
		<xsl:when test="$value = 'place'">002</xsl:when>
		<xsl:when test="$value = 'stratum'">003</xsl:when>
		<xsl:when test="$value = 'temporal'">004</xsl:when>
		<xsl:when test="$value = 'theme'">005</xsl:when>
		<xsl:otherwise>001</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!-- replace the mdChar enum -->
	<xsl:template match="mdChar">
		<xsl:element name="{local-name(.)}">
			<xsl:attribute name="ns"><xsl:value-of select="namespace-uri(.)"/></xsl:attribute>
			<xsl:element name="CharSetCd">
				<xsl:attribute name="value"><xsl:choose><xsl:when test=". = 'ucs2'">001</xsl:when><xsl:when test=". = 'ucs4'">002</xsl:when><xsl:when test=". = 'utf7'">003</xsl:when><xsl:when test=". = 'utf8'">004</xsl:when><xsl:when test=". = 'utf16'">005</xsl:when><xsl:when test=". = '8859part1'">006</xsl:when><xsl:when test=". = '8859part2'">007</xsl:when><xsl:when test=". = '8859part3'">008</xsl:when><xsl:when test=". = '8859part4'">009</xsl:when><xsl:when test=". = '8859part5'">010</xsl:when><xsl:when test=". = '8859part6'">011</xsl:when><xsl:when test=". = '8859part7'">012</xsl:when><xsl:when test=". = '8859part8'">013</xsl:when><xsl:when test=". = '8859part9'">014</xsl:when><xsl:when test=". = '8859part11'">015</xsl:when><xsl:when test=". = '8859part14'">016</xsl:when><xsl:when test=". = '8859part15'">017</xsl:when><xsl:when test=". = 'jis'">018</xsl:when><xsl:when test=". = 'shiftJIS'">019</xsl:when><xsl:when test=". = 'eucJP'">020</xsl:when><xsl:when test=". = 'usAscii'">021</xsl:when><xsl:when test=". = 'ebcdic'">022</xsl:when><xsl:when test=". = 'eucKR'">023</xsl:when><xsl:when test=". = 'big5'">024</xsl:when><xsl:otherwise>001</xsl:otherwise></xsl:choose></xsl:attribute>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	<!-- replace the mdHrLv enum -->
	<xsl:template match="mdHrLv | eur:scpLvl">
		<xsl:element name="{local-name(.)}">
			<xsl:attribute name="ns"><xsl:value-of select="namespace-uri(.)"/></xsl:attribute>
			<xsl:element name="ScopeCd">
				<xsl:attribute name="value"><xsl:choose><xsl:when test=". = 'attribute'">001</xsl:when><xsl:when test=". = 'attributeType'">002</xsl:when><xsl:when test=". = 'collectionHardware'">003</xsl:when><xsl:when test=". = 'collectionSession'">004</xsl:when><xsl:when test=". = 'dataset'">005</xsl:when><xsl:when test=". = 'series'">006</xsl:when><xsl:when test=". = 'nonGeographicDataset'">007</xsl:when><xsl:when test=". = 'dimensionGroup'">008</xsl:when><xsl:when test=". = 'feature'">009</xsl:when><xsl:when test=". = 'featureType'">010</xsl:when><xsl:when test=". = 'propertyType'">011</xsl:when><xsl:when test=". = 'fieldSession'">012</xsl:when><xsl:when test=". = 'software'">013</xsl:when><xsl:when test=". = 'service'">014</xsl:when><xsl:when test=". = 'model'">015</xsl:when><xsl:when test=". = 'tile'">016</xsl:when><xsl:otherwise>001</xsl:otherwise></xsl:choose></xsl:attribute>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	<!-- replace the orFunct enum -->
	<xsl:template match="iso19115:orFunct">
		<xsl:element name="{local-name(.)}">
			<xsl:attribute name="ns"><xsl:value-of select="namespace-uri(.)"/></xsl:attribute>
			<xsl:element name="OnFunctCd">
				<xsl:attribute name="value"><xsl:choose><xsl:when test=". = 'download'">001</xsl:when><xsl:when test=". = 'information'">002</xsl:when><xsl:when test=". = 'offlineAccess'">003</xsl:when><xsl:when test=". = 'order'">004</xsl:when><xsl:when test=". = 'search'">005</xsl:when><xsl:otherwise>001</xsl:otherwise></xsl:choose></xsl:attribute>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	<!-- replace the dimName enum -->
	<xsl:template match="iso19115:dimName">
		<xsl:element name="{local-name(.)}">
			<xsl:attribute name="ns"><xsl:value-of select="namespace-uri(.)"/></xsl:attribute>
			<xsl:element name="DimNameTypCd">
				<xsl:attribute name="value"><xsl:choose><xsl:when test=". = 'row'">001</xsl:when><xsl:when test=". = 'column'">002</xsl:when><xsl:when test=". = 'vertical'">003</xsl:when><xsl:when test=". = 'track'">004</xsl:when><xsl:when test=". = 'crossTrack'">005</xsl:when><xsl:when test=". = 'line'">006</xsl:when><xsl:when test=". = 'sample'">007</xsl:when><xsl:when test=". = 'time'">008</xsl:when><xsl:otherwise>001</xsl:otherwise></xsl:choose></xsl:attribute>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	<!-- replace the cellGeo enum -->
	<xsl:template match="eur:cellGeo">
		<xsl:element name="{local-name(.)}">
			<xsl:attribute name="ns"><xsl:value-of select="namespace-uri(.)"/></xsl:attribute>
			<xsl:element name="CellGeoCd">
				<xsl:attribute name="value"><xsl:choose><xsl:when test=". = 'point'">001</xsl:when><xsl:when test=". = 'area'">002</xsl:when><xsl:otherwise>001</xsl:otherwise></xsl:choose></xsl:attribute>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	<!-- change the format of the refDate value -->
	<xsl:template match="iso19115:refDate">
		<xsl:element name="{local-name(.)}">
			<xsl:attribute name="ns"><xsl:value-of select="namespace-uri(.)"/></xsl:attribute>
			<xsl:value-of select="substring-before(., '-')"/>
			<xsl:value-of select="substring(., 6, 2)"/>
			<xsl:value-of select="substring(., 9)"/>
		</xsl:element>
	</xsl:template>
	<!-- replace the uomName enum -->
	<xsl:template match="eur:uomName">
		<xsl:element name="{local-name(.)}">
			<xsl:attribute name="ns"><xsl:value-of select="namespace-uri(.)"/></xsl:attribute>
				<xsl:choose>
				<xsl:when test=". = 'foot'">Feet</xsl:when>
				<xsl:when test=". = 'kilometer'">Kilometers</xsl:when>
				<xsl:when test=". = 'meter'">Meters</xsl:when>
				<xsl:when test=". = 'mile'">Miles</xsl:when>
				<xsl:when test=". = 'yard'">Yards</xsl:when>
				<xsl:otherwise>Unknown</xsl:otherwise>
				</xsl:choose>
		</xsl:element>
	</xsl:template>
	<!-- Esri format for the temporal extent -->
	<xsl:template match="eur:tempEle">
		<xsl:element name="{local-name(.)}">
			<xsl:element name="TempExtent">
				<xsl:element name="exTemp">
					<xsl:element name="TM_GeometricPrimitive">
						<xsl:for-each select="eur:exTemp/eur:beginEnd">
							<xsl:element name="TM_Period">
								<xsl:element name="begin">
									<xsl:value-of select="substring(eur:begin, 1, 4)"/><xsl:value-of select="substring(eur:begin, 6, 2)"/><xsl:value-of select="substring(eur:begin, 9, 2)"/>T<xsl:value-of select="substring(eur:begin, 12, 2)"/><xsl:value-of select="substring(eur:begin, 15, 2)"/><xsl:value-of select="substring(eur:begin, 18, 2)"/>
								</xsl:element>
								<xsl:element name="end">
									<xsl:value-of select="substring(eur:end, 1, 4)"/><xsl:value-of select="substring(eur:end, 6, 2)"/><xsl:value-of select="substring(eur:end, 9, 2)"/>T<xsl:value-of select="substring(eur:end, 12, 2)"/><xsl:value-of select="substring(eur:end, 15, 2)"/><xsl:value-of select="substring(eur:end, 18, 2)"/>
								</xsl:element>
							</xsl:element>
						</xsl:for-each>
					</xsl:element>
				</xsl:element>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	<!-- replace the medName enum -->
	<xsl:template match="eur:medName">
		<xsl:element name="{local-name(.)}">
			<xsl:attribute name="ns"><xsl:value-of select="namespace-uri(.)"/></xsl:attribute>
			<xsl:element name="MedNameCd">
				<xsl:attribute name="value">
				<xsl:choose>
				<xsl:when test=". = 'cdRom'">001</xsl:when>
				<xsl:when test=". = 'dvd'">002</xsl:when>
				<xsl:when test=". = 'dvdRom'">003</xsl:when>
				<xsl:when test=". = '3halfInchFloppy'">004</xsl:when>
				<xsl:when test=". = '5quarterInchFloppy'">005</xsl:when>
				<xsl:when test=". = '7trackTape'">006</xsl:when>
				<xsl:when test=". = '9trackTape'">007</xsl:when>
				<xsl:when test=". = '3480Cartridge'">008</xsl:when>
				<xsl:when test=". = '3490Cartridge'">009</xsl:when>
				<xsl:when test=". = '3580Cartridge'">010</xsl:when>
				<xsl:when test=". = '4mmCartridgeTape'">011</xsl:when>
				<xsl:when test=". = '8mmCartridgeTape'">012</xsl:when>
				<xsl:when test=". = '1quarterInchCartridgeTape'">013</xsl:when>
				<xsl:when test=". = 'digitalLinearTape'">014</xsl:when>
				<xsl:when test=". = 'onLine'">015</xsl:when>
				<xsl:when test=". = 'satellite'">016</xsl:when>
				<xsl:when test=". = 'telephoneLink'">017</xsl:when>
				<xsl:when test=". = 'hardcopy'">018</xsl:when>
				<xsl:otherwise>001</xsl:otherwise>
				</xsl:choose></xsl:attribute>
			</xsl:element>
		</xsl:element>
	</xsl:template>
</xsl:stylesheet>
